# Altearn RPC

## Dépendances

- Python 3.8+ 
- PyPresence
- TQDM

PyPresence et TQDM sont installés automatiquement par pip

## Installation
`pip install altearnrpc`


## Mise à jour
`pip install -U altearnrpc`

## Démarrage
`python -m altearnrpc`